@@ -1,6 +1,9 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pmb.chroot.init import init as init, init_keys as init_keys
+from pmb.chroot.init import (
+    init as init,
+    init_keys as init_keys,
+)
 from pmb.chroot.mount import (
     mount as mount,
     mount_native_into_foreign as mount_native_into_foreign,
@@ -10,8 +13,11 @@ from pmb.chroot.run import (
     root as root,
     rootm as rootm,
     user as user,
-    userm as userm,
     user_exists as user_exists,
+    userm as userm,
 )
 from pmb.chroot.shutdown import shutdown as shutdown
-from pmb.chroot.zap import zap as zap, del_chroot as del_chroot
+from pmb.chroot.zap import (
+    del_chroot as del_chroot,
+    zap as zap,
+)
