@@ -1,13 +1,13 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
+
+import pmb.chroot.apk
+import pmb.config
+from pmb.core import Chroot
 from pmb.core.pkgrepo import pkgrepo_iglob
 from pmb.helpers import logging
 
-import pmb.config
-import pmb.chroot.apk
-from pmb.core import Chroot
-
 
 def list_chroot(suffix: Chroot, remove_prefix: bool = True) -> list[str]:
     ret = []
@@ -52,7 +52,5 @@ def delete(hook: str, suffix: Chroot) -> None:
 
 
 def update(suffix: Chroot) -> None:
-    """
-    Rebuild and update all hooks that are out of date
-    """
+    """Rebuild and update all hooks that are out of date"""
     pmb.chroot.apk.install(list_chroot(suffix, False), suffix)
