@@ -1,13 +1,13 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
-from pathlib import Path, PurePath
 import subprocess
 from collections.abc import Sequence
-from typing import overload, Literal
+from pathlib import Path, PurePath
+from typing import Literal, overload
 
-import pmb.config
 import pmb.chroot
+import pmb.config
 import pmb.helpers.run_core
 from pmb.core import Chroot
 from pmb.types import (
@@ -45,7 +45,6 @@ def rootm(
     See pmb.helpers.run_core.core() for a detailed description of all other
     arguments and the return value.
     """
-
     # Convert any Path objects to their string representation
     cmd_strs = [[os.fspath(x) for x in cmd] for cmd in cmds]
 
