@@ -1,25 +1,29 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import os
-from pathlib import Path
-from pmb.types import PathString
 import sys
 from collections.abc import Sequence
+from pathlib import Path
 
 #
 # Exported functions
 #
 # FIXME (#2324): this sucks, we should re-organise this and not rely on "lifting"
 # this functions this way
-from pmb.config.file import load as load, save as save, serialize as serialize
-from pmb.config.sudo import which_sudo
-from pmb.config.other import is_systemd_selected as is_systemd_selected
-from .init import (
-    require_programs as require_programs,
-    ask_for_mainline_downstream as ask_for_mainline_downstream,
+from pmb.config.file import (
+    load as load,
+    save as save,
+    serialize as serialize,
 )
-from . import workdir as workdir
+from pmb.config.other import is_systemd_selected as is_systemd_selected
+from pmb.config.sudo import which_sudo
+from pmb.types import PathString
 
+from . import workdir as workdir
+from .init import (
+    ask_for_mainline_downstream as ask_for_mainline_downstream,
+    require_programs as require_programs,
+)
 
 #
 # Exported variables (internal configuration)
@@ -33,8 +37,8 @@ apk_keys_path: Path = pmb_src / "pmb/data/keys"
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
 apk_tools_min_version = {
-    "edge": "3.0.2-r0",
-    "v3.23": "3.0.2-r0",
+    "edge": "3.0.3-r1",
+    "v3.23": "3.0.3-r1",
     "v3.22": "2.14.9-r3",
     "v3.21": "2.14.6-r3",
     "v3.20": "2.14.4-r1",
@@ -127,6 +131,7 @@ filesystems = {
     "f2fs": "f2fs-tools",
     "fat16": "dosfstools",
     "fat32": "dosfstools",
+    "xfs": "xfsprogs",
 }
 
 # Legacy channels and their new names (pmb#2015)
@@ -211,6 +216,8 @@ chroot_device_nodes = [
     [666, "c", 1, 7, "full"],
     [644, "c", 1, 8, "random"],
     [644, "c", 1, 9, "urandom"],
+    [666, "c", 5, 0, "tty"],
+    [666, "c", 5, 2, "ptmx"],
 ]
 
 # Age in hours that we keep the APKINDEXes before downloading them again.
