@@ -7,7 +7,8 @@ from functools import lru_cache
 
 @lru_cache
 def which_sudo() -> str | None:
-    """Return a command required to run commands as root, if any.
+    """
+    Return a command required to run commands as root, if any.
 
     Find whether sudo or doas is installed for commands that require root.
     Allows user to override preferred sudo with PMB_SUDO env variable.
