@@ -1,12 +1,10 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import json
-from collections.abc import Sequence
-from pmb.core.arch import Arch
-from pmb.helpers import logging
 import os
-from pathlib import Path
 import sys
+from collections.abc import Sequence
+from pathlib import Path
 from typing import Any, NoReturn
 
 import pmb.aportgen
@@ -17,8 +15,6 @@ import pmb.chroot.initfs
 import pmb.chroot.other
 import pmb.ci
 import pmb.config
-from pmb.core import Config
-from pmb.types import Env, PmbArgs, RunOutputTypeDefault
 import pmb.export
 import pmb.helpers.aportupgrade
 import pmb.helpers.git
@@ -36,12 +32,16 @@ import pmb.parse
 import pmb.parse.apkindex
 import pmb.qemu
 import pmb.sideload
-from pmb.core import ChrootType, Chroot
+from pmb.core import Chroot, ChrootType, Config
+from pmb.core.arch import Arch
 from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.types import Env, PmbArgs, RunOutputTypeDefault
 
 
 def _parse_flavor(device: str, autoinstall: bool = True) -> str:
-    """Verify the flavor argument if specified, or return a default value.
+    """
+    Verify the flavor argument if specified, or return a default value.
 
     :param autoinstall: make sure that at least one kernel flavor is installed
     """
@@ -137,12 +137,20 @@ def build_init(args: PmbArgs) -> None:
 
 def checksum(args: PmbArgs) -> None:
     pmb.chroot.init(Chroot.native())
-    for package in args.packages:
+
+    packages = pmb.helpers.git.get_changed_packages() if args.changed else args.packages
+
+    for package in packages:
         if args.verify:
             pmb.build.checksum.verify(package)
         else:
             pmb.build.checksum.update(package)
 
+    if not packages:
+        # We should only ever reach this if the --changed argument is used as
+        # otherwise at least one package must be specified in the arguments.
+        logging.info("NOTE: No changed packages detected, not updating any checksums")
+
 
 def sideload(args: PmbArgs) -> None:
     arch = args.arch
