@@ -1,21 +1,21 @@
 # Copyright 2024 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import configparser
+import os
+import re
 from enum import Enum
 from glob import glob
 from pathlib import Path
 from typing import Final
 from urllib.parse import urlparse
-from pmb.core.context import get_context
-from pmb.core.pkgrepo import pkgrepo_default_path, pkgrepo_path, pkgrepo_name
-from pmb.helpers import logging
-from pmb.helpers.exceptions import NonBugError
-import os
-import re
 
 import pmb.config
 import pmb.helpers.pmaports
 import pmb.helpers.run
+from pmb.core.context import get_context
+from pmb.core.pkgrepo import pkgrepo_default_path, pkgrepo_name, pkgrepo_path
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
 from pmb.meta import Cache
 from pmb.types import PathString, RunOutputTypeDefault
 
@@ -24,7 +24,8 @@ re_branch_pmaports = re.compile(r"^v\d\d\.\d\d$")
 
 
 def get_path(name_repo: str) -> Path:
-    """Get the path to the repository.
+    """
+    Get the path to the repository.
 
     The path is either the default one in the work dir, or a user-specified one in args.
 
@@ -36,7 +37,8 @@ def get_path(name_repo: str) -> Path:
 
 
 def clone(name_repo: str, do_shallow_clone: bool = False) -> None:
-    """Clone a git repository to $WORK/cache_git/$name_repo.
+    """
+    Clone a git repository to $WORK/cache_git/$name_repo.
 
     (or to the overridden path set in args, as with ``pmbootstrap --aports``).
 
@@ -72,7 +74,8 @@ def clone(name_repo: str, do_shallow_clone: bool = False) -> None:
 def rev_parse(
     path: Path, revision: str = "HEAD", extra_args: list = [], silent: bool = False
 ) -> str:
-    """Run "git rev-parse" in a specific repository dir.
+    """
+    Run "git rev-parse" in a specific repository dir.
 
     :param path: to the git repository
     :param extra_args: additional arguments for ``git rev-parse``. Pass
@@ -130,7 +133,8 @@ def remote_to_name_and_clean_url(remote_line: str) -> tuple[str, str]:
 
 
 def get_upstream_remote(aports: Path) -> str:
-    """Find the remote, which matches the git URL from the config.
+    """
+    Find the remote, which matches the git URL from the config.
 
     Usually "origin", but the user may have set up their git repository differently.
     """
@@ -196,7 +200,6 @@ OUTDATED_GIT_REMOTES_SSH: Final[list[str]] = ["git@gitlab.com:postmarketos/pmapo
 
 def migrate_upstream_remote() -> None:
     """Migrate pmaports git remote URL from gitlab.com to gitlab.postmarketos.org."""
-
     repo = pkgrepo_default_path()
     repo_name = repo.parts[-1]
     lines = list_remotes(repo)
@@ -227,7 +230,8 @@ def migrate_upstream_remote() -> None:
 
 @Cache("aports")
 def parse_channels_cfg(aports: Path) -> dict:
-    """Parse channels.cfg from pmaports.git, origin/master branch.
+    """
+    Parse channels.cfg from pmaports.git, origin/master branch.
 
     Reference: https://postmarketos.org/channels.cfg
 
@@ -254,13 +258,13 @@ def parse_channels_cfg(aports: Path) -> dict:
                 command, aports, output=RunOutputTypeDefault.NULL, check=False
             )
             cfg.read_string(stdout)
-    except configparser.MissingSectionHeaderError:
+    except configparser.MissingSectionHeaderError as exception:
         logging.info("NOTE: fix this by fetching your pmaports.git, e.g. with 'pmbootstrap pull'")
         raise RuntimeError(
             "Failed to read channels.cfg from"
             f" '{remote}/master' branch of your local"
             " pmaports clone"
-        )
+        ) from exception
 
     # Meta section
     ret: dict[str, dict[str, str | dict[str, str]]] = {"channels": {}}
@@ -283,7 +287,8 @@ def parse_channels_cfg(aports: Path) -> dict:
 
 
 def branch_looks_official(repo: Path, branch: str) -> bool:
-    """Check if a given branch follows the patterns of official branches in
+    """
+    Check if a given branch follows the patterns of official branches in
        pmaports or aports.
 
     :returns: True if it looks official, False otherwise
@@ -300,7 +305,8 @@ def branch_looks_official(repo: Path, branch: str) -> bool:
 
 
 def pull(repo_name: str) -> int:
-    """Check if on official branch and essentially try ``git pull --ff-only``.
+    """
+    Check if on official branch and essentially try ``git pull --ff-only``.
 
     Instead of really doing ``git pull --ff-only``, do it in multiple steps
     (``fetch, merge --ff-only``), so we can display useful messages depending
@@ -370,7 +376,8 @@ def pull(repo_name: str) -> int:
 
 
 def get_topdir(repo: Path) -> Path:
-    """Get top-dir of git repo.
+    """
+    Get top-dir of git repo.
 
     :returns: the top dir of the git repository
     """
@@ -383,7 +390,8 @@ def get_topdir(repo: Path) -> Path:
 
 
 def get_files(repo: Path, include_dot_git_dir: bool = False) -> list[str]:
-    """Get all files inside a git repository, that are either already in the git tree or are not in gitignore.
+    """
+    Get all files inside a git repository, that are either already in the git tree or are not in gitignore.
 
     Do not list deleted files. To be used for creating a tarball of the git repository.
 
@@ -404,3 +412,78 @@ def get_files(repo: Path, include_dot_git_dir: bool = False) -> list[str]:
             ret += [file]
 
     return ret
+
+
+def get_changed_files() -> set[Path]:
+    """Get all changed files.
+
+    Provides a set of all file paths that have uncommitted changes—both staged
+    and unstaged—in the default package repository's git repository (usually
+    pmaports).
+
+    :returns: Set of changed file paths.
+    """
+    # Changed files
+    ret = set()
+    for file_string in pmb.helpers.run.user_output(
+        # Diff against HEAD so we get both staged and unstaged changes.
+        ["git", "diff", "--name-only", "HEAD"],
+        working_dir=pkgrepo_default_path(),
+    ).splitlines():
+        file = Path(file_string)
+
+        if (pkgrepo_default_path() / file).exists():
+            ret.add(file)
+    return ret
+
+
+def _is_path_hidden(maybe_hidden: Path) -> bool:
+    """Check whether a path would be considered hidden on Unix systems.
+
+    Attempts to determine whether a path would be considered hidden on a Unix
+    system.
+
+    :param maybe_hidden: Path to analyse.
+    :returns: True if the path is to be considered hidden, False otherwise.
+    """
+    return any(part[0] == "." for part in maybe_hidden.parts)
+
+
+def get_changed_packages() -> set[str]:
+    """Get all changed packages.
+
+    Provides a set of the names of all packages that have uncommitted
+    changes—both staged and unstaged—in the default package repository's git
+    repository (usually pmaports).
+
+    :returns: Set of the names of changed packages.
+    """
+    ret = set()
+    for file in get_changed_files():
+        # Skip files:
+        # * in the root dir of pmaports (e.g. README.md)
+        # * path with a dot (e.g. .ci/, device/.shared-patches/)
+        if not file.parent or _is_path_hidden(file):
+            continue
+
+        dirname = file.parent
+        if file.name != "APKBUILD":
+            # Walk up directories until we (eventually) find the package
+            # the file belongs to (could be in a subdirectory of a package)
+            while dirname and not (pkgrepo_default_path() / dirname / "APKBUILD").exists():
+                dirname = dirname.parent
+
+            # Unable to find APKBUILD the file belong to
+            if not dirname:
+                # ... maybe the package was deleted entirely?
+                if not (pkgrepo_default_path() / file).exists():
+                    continue
+
+                # Weird, file does not belong to any package?
+                continue
+        elif not (pkgrepo_default_path() / file).exists():
+            continue  # APKBUILD was deleted
+
+        ret.add(dirname.name)
+
+    return ret
