@@ -8,25 +8,25 @@ See also:
 - pmb/helpers/package.py (work with both)
 """
 
-import os
 import hashlib
-from pmb.helpers.exceptions import NonBugError
-from pmb.core.context import get_context
-from pmb.core.arch import Arch
-from pmb.core.pkgrepo import pkgrepo_names
-from pmb.helpers import logging
+import os
 from pathlib import Path
 from typing import Literal
 
 import pmb.config.pmaports
-from pmb.meta import Cache
 import pmb.helpers.http
 import pmb.helpers.run
-import pmb.helpers.other
+from pmb.core.arch import Arch
+from pmb.core.context import get_context
+from pmb.core.pkgrepo import pkgrepo_names
+from pmb.helpers import logging
+from pmb.helpers.exceptions import NonBugError
+from pmb.meta import Cache
 
 
 def apkindex_hash(url: str, length: int = 8) -> Path:
-    r"""Generate the hash that APK adds to the APKINDEX and apk packages in its apk cache folder.
+    r"""
+    Generate the hash that APK adds to the APKINDEX and apk packages in its apk cache folder.
 
     It is the "12345678" part in this example:
     "APKINDEX.12345678.tar.gz".
@@ -58,7 +58,8 @@ def apkindex_hash(url: str, length: int = 8) -> Path:
 def urls(
     user_repository: Path | None = None, mirrors_exclude: list[str] | Literal[True] = []
 ) -> list[str]:
-    """Get a list of repository URLs, as they are in /etc/apk/repositories.
+    """
+    Get a list of repository URLs, as they are in /etc/apk/repositories.
 
     :param user_repository: add /mnt/pmbootstrap/packages
     :param mirrors_exclude: mirrors to exclude (see pmb.core.config.Mirrors) or true to exclude
@@ -77,8 +78,7 @@ def urls(
 
     # Local user repository (for packages compiled with pmbootstrap)
     if user_repository:
-        for channel in pmb.config.pmaports.all_channels():
-            ret.append(str(user_repository / channel))
+        ret.extend(str(user_repository / channel) for channel in pmb.config.pmaports.all_channels())
 
     if mirrors_exclude is True:
         return ret
@@ -127,7 +127,8 @@ def urls(
 def apkindex_files(
     arch: Arch | None = None, user_repository: bool = True, exclude_mirrors: list[str] = []
 ) -> list[Path]:
-    """Get a list of outside paths to all resolved APKINDEX.tar.gz files for a specific arch.
+    """
+    Get a list of outside paths to all resolved APKINDEX.tar.gz files for a specific arch.
 
     :param arch: defaults to native
     :param user_repository: add path to index of locally built packages
@@ -137,23 +138,28 @@ def apkindex_files(
     if not arch:
         arch = Arch.native()
 
-    ret = []
+    ret: list[Path] = []
     # Local user repository (for packages compiled with pmbootstrap)
     if user_repository:
-        for channel in pmb.config.pmaports.all_channels():
-            ret.append(get_context().config.work / "packages" / channel / arch / "APKINDEX.tar.gz")
+        ret.extend(
+            get_context().config.work / "packages" / channel / arch / "APKINDEX.tar.gz"
+            for channel in pmb.config.pmaports.all_channels()
+        )
 
     # Resolve the APKINDEX.$HASH.tar.gz files
-    for url in urls(False, exclude_mirrors):
-        ret.append(get_context().config.work / f"cache_apk_{arch}" / apkindex_hash(url))
+    ret.extend(
+        file
+        for url in urls(False, exclude_mirrors)
+        if (file := get_context().config.work / f"cache_apk_{arch}" / apkindex_hash(url)).exists()
+    )
 
     return ret
 
 
 @Cache("arch", force=False)
-def _update(arch: Arch | None, force: bool, existing_only: bool) -> bool:
-    """Internal method for downloading the APKINDEX files. This should not be called directly, use
-    update() instead.
+def update(arch: Arch | None = None, force: bool = False, existing_only: bool = False) -> bool:
+    """
+    Download the APKINDEX files for all URLs depending on the architectures.
 
     :param arch: * one Alpine architecture name ("x86_64", "armhf", ...)
                  * None for all architectures
@@ -169,7 +175,8 @@ def _update(arch: Arch | None, force: bool, existing_only: bool) -> bool:
         return False
 
     # Architectures and retention time
-    architectures = [arch] if arch else Arch.supported_binary()
+    supported_binary = Arch.supported_binary()
+    architectures = [arch] if arch else supported_binary
     retention_hours = pmb.config.apkindex_retention_time
     retention_seconds = retention_hours * 3600
 
@@ -221,7 +228,10 @@ def _update(arch: Arch | None, force: bool, existing_only: bool) -> bool:
         pmb.helpers.cli.progress_print(i / len(outdated))
         temp = pmb.helpers.http.download(url, "APKINDEX", False, logging.DEBUG, True, True)
         if not temp:
-            if os.environ.get("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1":
+            if (
+                os.environ.get("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1"
+                or arch not in supported_binary
+            ):
                 missing_ignored = True
                 continue
             else:
@@ -235,35 +245,15 @@ def _update(arch: Arch | None, force: bool, existing_only: bool) -> bool:
 
     if missing_ignored:
         logging.warn_once(
-            "NOTE: ignoring missing APKINDEX due to PMB_APK_FORCE_MISSING_REPOSITORIES=1 (fine during bootstrap)"
+            "NOTE: ignoring missing APKINDEX due to PMB_APK_FORCE_MISSING_REPOSITORIES=1 or architecture without binary repo (fine during bootstrap)"
         )
 
     return True
 
 
-def update(arch: Arch | None = None, force: bool = False, existing_only: bool = False) -> bool:
-    """Download the APKINDEX files for all URLs depending on the architectures.
-
-    :param arch: * one Alpine architecture name ("x86_64", "armhf", ...)
-                 * None for all architectures
-    :param force: even update when the APKINDEX file is fairly recent
-    :param existing_only: only update the APKINDEX files that already exist,
-                          this is used by "pmbootstrap update"
-
-    :returns: True when files have been downloaded, False otherwise
+def alpine_apkindex_path(repo: str = "main", arch: Arch | None = None) -> Path:
     """
-    apkindex_path = alpine_apkindex_path(arch=arch, with_update=False)
-
-    if not apkindex_path.exists() or force:
-        return _update(arch, force, existing_only)
-
-    return True
-
-
-def alpine_apkindex_path(
-    repo: str = "main", arch: Arch | None = None, with_update: bool = True
-) -> Path:
-    """Get the path to a specific Alpine APKINDEX file on disk and download it if necessary.
+    Get the path to a specific Alpine APKINDEX file on disk and download it if necessary.
 
     :param repo: Alpine repository name (e.g. "main")
     :param arch: Alpine architecture (e.g. "armhf"), defaults to native arch.
@@ -275,8 +265,7 @@ def alpine_apkindex_path(
 
     # Download the file
     arch = arch or Arch.native()
-    if with_update:
-        update(arch)
+    update(arch)
 
     # Find it on disk
     channel_cfg = pmb.config.pmaports.read_config_channel()
