@@ -1,10 +1,8 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
-from pmb.core.arch import Arch
-from pmb.helpers import logging
+import glob
 import os
 import re
-import glob
 import shlex
 import sys
 from collections.abc import Sequence
@@ -16,22 +14,23 @@ import pmb.chroot.apk
 import pmb.chroot.initfs
 import pmb.config
 import pmb.config.pmaports
-from pmb.helpers.locale import get_xkb_layout
-import pmb.parse.depends
-from pmb.parse.deviceinfo import Deviceinfo
-from pmb.core import Config
-from pmb.types import Env, PartitionLayout, PmbArgs, RunOutputTypeDefault
 import pmb.helpers.devices
-from pmb.helpers.mount import mount_device_rootfs
-import pmb.helpers.run
 import pmb.helpers.other
 import pmb.helpers.package
+import pmb.helpers.run
+import pmb.install
 import pmb.install.blockdevice
 import pmb.install.recovery
 import pmb.install.ui
-import pmb.install
-from pmb.core import Chroot, ChrootType
+import pmb.parse.depends
+from pmb.core import Chroot, ChrootType, Config
+from pmb.core.arch import Arch
 from pmb.core.context import get_context
+from pmb.helpers import logging
+from pmb.helpers.locale import get_xkb_layout
+from pmb.helpers.mount import mount_device_rootfs
+from pmb.parse.deviceinfo import Deviceinfo
+from pmb.types import Env, PartitionLayout, PmbArgs, RunOutputTypeDefault
 
 # Keep track of the packages we already visited in get_recommends() to avoid
 # infinite recursion
@@ -161,9 +160,7 @@ def copy_files_from_chroot(chroot: Chroot, rsync: bool, verbose: bool) -> None:
 
 
 def create_home_from_skel(filesystem: str, user: str) -> None:
-    """
-    Create /home/{user} from /etc/skel
-    """
+    """Create /home/{user} from /etc/skel"""
     rootfs = Chroot.native() / "mnt/install"
     # In btrfs, home subvol & home dir is created in format.py
     if filesystem != "btrfs":
@@ -248,8 +245,7 @@ def setup_login_chpasswd_user_from_arg(args: PmbArgs, user: str, chroot: Chroot)
     path = "/tmp/pmbootstrap_chpasswd_in"
     path_outside = chroot / path
 
-    with open(path_outside, "w", encoding="utf-8") as handle:
-        handle.write(f"{user}:{args.password}")
+    path_outside.write_text(f"{user}:{args.password}", encoding="utf-8")
 
     pmb.chroot.root(["sh", "-c", f"cat {shlex.quote(path)} | chpasswd"], chroot)
 
@@ -302,9 +298,7 @@ def setup_login(args: PmbArgs, config: Config, chroot: Chroot) -> None:
 
 
 def copy_ssh_keys(config: Config) -> None:
-    """
-    If requested, copy user's SSH public keys to the device if they exist
-    """
+    """If requested, copy user's SSH public keys to the device if they exist"""
     if not config.ssh_keys:
         return
     keys = []
@@ -340,9 +334,7 @@ def copy_ssh_keys(config: Config) -> None:
 
 
 def setup_keymap(config: Config) -> None:
-    """
-    Set the keymap with the setup-keymap utility if the device requires it
-    """
+    """Set the keymap with the setup-keymap utility if the device requires it"""
     chroot = Chroot(ChrootType.ROOTFS, config.device)
     deviceinfo = pmb.parse.deviceinfo(device=config.device)
     if not deviceinfo.keymaps or deviceinfo.keymaps.strip() == "":
@@ -409,9 +401,7 @@ def setup_timezone(chroot: Chroot, timezone: str) -> None:
 
 
 def setup_locale(chroot: Chroot, locale: str) -> None:
-    """
-    Set locale-related settings such as $LANG and keyboard layout
-    """
+    """Set locale-related settings such as $LANG and keyboard layout"""
     # 10locale-pmos.sh gets sourced before 20locale.sh from
     # alpine-baselayout by /etc/profile. Since they don't override the
     # locale if it exists, it warranties we have preference
@@ -435,16 +425,13 @@ def setup_locale(chroot: Chroot, locale: str) -> None:
         config_tmp_path = f"/tmp/{config_name}"
         config_path = f"/etc/X11/xorg.conf.d/{config_name}"
         pmb.chroot.root(["mkdir", "-p", "/etc/X11/xorg.conf.d"], chroot)
-        with open(chroot / config_tmp_path, "w") as f:
-            f.write(kb_config)
+        (chroot / config_tmp_path).write_text(kb_config)
         pmb.chroot.root(["mv", config_tmp_path, config_path], chroot)
         pmb.chroot.root(["chown", "root:root", config_path], chroot)
 
 
 def setup_hostname(device: str, hostname: str | None) -> None:
-    """
-    Set the hostname and update localhost address in /etc/hosts
-    """
+    """Set the hostname and update localhost address in /etc/hosts"""
     # Default to device name. If device name is not a valid hostname then
     # default to a static default.
     if not hostname:
@@ -620,8 +607,10 @@ def generate_binary_list(args: PmbArgs, chroot: Chroot, step: int) -> list[tuple
         binary, offset_ = binary_offset.split(":")
         try:
             offset = int(offset_)
-        except ValueError:
-            raise RuntimeError(f"Value for firmware binary offset is not valid: {offset}")
+        except ValueError as exception:
+            raise RuntimeError(
+                f"Value for firmware binary offset is not valid: {offset}"
+            ) from exception
         binary_path = chroot / "usr/share" / binary
         if not os.path.exists(binary_path):
             raise RuntimeError(
@@ -674,10 +663,10 @@ def embed_firmware(args: PmbArgs, suffix: Chroot) -> None:
     if pmb.parse.deviceinfo().sd_embed_firmware_step_size:
         try:
             step = int(pmb.parse.deviceinfo().sd_embed_firmware_step_size or "invalid")
-        except ValueError:
+        except ValueError as exception:
             raise RuntimeError(
                 f"Value for deviceinfo_sd_embed_firmware_step_size is not valid: {step}"
-            )
+            ) from exception
 
     device_rootfs = mount_device_rootfs(suffix)
     binary_list = generate_binary_list(args, suffix, step)
@@ -730,8 +719,7 @@ def sanity_check_disk(args: PmbArgs) -> None:
     if not os.path.exists(device):
         raise RuntimeError(f"{device} doesn't exist, is the disk plugged?")
     if os.path.isdir(f"/sys/class/block/{device_name}"):
-        with open(f"/sys/class/block/{device_name}/ro") as handle:
-            ro = handle.read()
+        ro = Path(f"/sys/class/block/{device_name}/ro").read_text()
         if ro == "1\n":
             raise RuntimeError(f"{device} is read-only, maybe a locked SD card?")
 
@@ -744,8 +732,7 @@ def sanity_check_disk_size(args: PmbArgs) -> None:
         # This is a best-effort sanity check, continue if it's not checkable
         return
 
-    with open(sysfs) as handle:
-        raw = handle.read()
+    raw = Path(sysfs).read_text()
 
     # Size is in 512-byte blocks
     size = int(raw.strip())
@@ -860,7 +847,6 @@ def create_fstab(args: PmbArgs, layout: PartitionLayout | None, chroot: Chroot)
     :param layout: partition layout from get_partition_layout() or None
     :param chroot: of the chroot, which fstab will be created to
     """
-
     # Do not install fstab into target rootfs when using on-device
     # installer. Provide fstab only to installer suffix
     if args.on_device_installer and chroot.type == ChrootType.ROOTFS:
@@ -1067,8 +1053,10 @@ def install_system_image(
 def print_flash_info(
     device: str, deviceinfo: Deviceinfo, split: bool, have_disk: bool, single_partition: bool
 ) -> None:
-    """Print flashing information, based on the deviceinfo data and the
-    pmbootstrap arguments."""
+    """
+    Print flashing information, based on the deviceinfo data and the
+    pmbootstrap arguments.
+    """
     logging.info("")  # make the note stand out
     logging.info("*** FLASHING INFORMATION ***")
 
