@@ -1,15 +1,17 @@
 # Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
+from pmb.parse._apkbuild import (
+    apkbuild as apkbuild,
+    function_body as function_body,
+)
 from pmb.parse.arguments import (
     arguments as arguments,
-    arguments_install as arguments_install,
     arguments_flasher as arguments_flasher,
+    arguments_install as arguments_install,
     get_parser as get_parser,
 )
-from pmb.parse._apkbuild import apkbuild as apkbuild
-from pmb.parse._apkbuild import function_body as function_body
 from pmb.parse.binfmt_info import binfmt_info as binfmt_info
-from pmb.parse.deviceinfo import deviceinfo as deviceinfo
-from pmb.parse.kconfig import check as check
 from pmb.parse.bootimg import bootimg as bootimg
 from pmb.parse.cpuinfo import arm_big_little_first_group_ncpus as arm_big_little_first_group_ncpus
+from pmb.parse.deviceinfo import deviceinfo as deviceinfo
+from pmb.parse.kconfig import check as check
